gs.as_graph: To Graph Helper

Description Usage Arguments Value Author(s)

Description

reconstruct a matrix from an adjacency matrix using vertex attributes retained from a reference graph that was passed as input.

Usage

1
gs.as_graph(A, gref = NULL, edge.attr = NULL)

Arguments

A

the n x n adjacency matrix.

gref

a reference graph to use for adding vertex attributes.

edge.attr

the edge attribute to (optionally) add weights from the adjacency matrix to.

Value

the graph as an igraph object.

Author(s)

Eric Bridgeford


neurodata/graphstats documentation built on May 14, 2019, 5:19 p.m.