gs.siem.sample.test: Estimator Sample Test

Description Usage Arguments Value

Description

A function that computes the p value of falsely rejecting H0 that x_i !? x_j in favor of HA that x_j ? x_i for x_i, x_j from the same sample.

Usage

1
2
gs.siem.sample.test(x1, x2, var1, var2, df = NULL, n1 = NULL, n2 = NULL,
  alt = "greater")

Arguments

x1

expectation value of an estimator.

x2

expectation value of a second estimator.

var1

the variance of the first estimator.

var2

the variance of the second estimator.

df=NULL

the number of degrees of freedom involved. Ignored if n1 and n2 are provided.

n1=NULL

the number of observations for the first estimator. If n1 and n2 are not provided, the number of degrees of freedom is set to df.

n2=NULL

the number of observations for the second estimator. If n1 and n2 are not provided, the number of degrees of freedom is set to df.

  • 1x1 and x2 are from different samples

  • 2x1 and x2 are from different samples

alt='greater'

the alternative hypothesis for each edge test.

  • 'greater'p corresponds to H0: x1 <= x2, HA: x1 > x2. R(x1, x2) = x1 > x2

  • 'neq'p corresponds to H0: x1 = x2, HA: x1 != x2. R(x1, x2) = x1 != x2

  • 'less'p corresponds to H0: x1 >= x2, HA: x1 < x2. R(x1, x2) = x1 < x2

Value

p is the p-value of false rejection of H0 that !R(x1, x2) in favor of HA that R(x1, x2).


neurodata/graphstats documentation built on May 14, 2019, 5:19 p.m.