Description Usage Arguments Value Author(s)
reconstruct a matrix from an adjacency matrix using vertex attributes retained from a reference graph that was passed as input.
1 | gs.as_graph(A, gref = NULL, edge.attr = NULL)
|
A |
the n x n adjacency matrix. |
gref |
a reference graph to use for adding vertex attributes. |
edge.attr |
the edge attribute to (optionally) add weights from the adjacency matrix to. |
the graph as an igraph object.
Eric Bridgeford
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.