Description Usage Arguments Value Author(s)
It extracts a (non-zero) edge weight vector W from a graph and replaces it with 2*R / (|E|+1) where R is the rank of W and |E| is the number of edges. This does 'no-op' for an unweighted or binary graph.
1 | gs.edge.ptr(g, edge.attr = NULL, output.type = "matrix")
|
g |
an |
edge.attr |
if
|
output.type |
the type of output to produce for the between community expectations. Defaults to
|
an igraph object or an nxn adjacency matrix with n vertices depending on output.type.
Eric Bridgeford ericwb95@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.